@@ -1,6 +1,5 @@
 package Text::Amuse;
 
-use 5.010001;
 use strict;
 use warnings;
 # use Data::Dumper;
@@ -14,11 +13,11 @@ Text::Amuse - Generate HTML and LaTeX documents from Emacs Muse markup.
 
 =head1 VERSION
 
-Version 0.60
+Version 0.61
 
 =cut
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 
 =head1 SYNOPSIS
@@ -277,7 +276,7 @@ sub raw_html_toc {
             unshift @toc, {
                            index => 0,
                            level => 2,
-                           string => "start body",
+                           string => $html->header->{title} || "start body",
                           };
         }
         else {
